==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/mprisplayer_mediaplayer/translations/mprisplayer_mediaplayer_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>@default</name>
    <message>
        <source>MediaPlayer</source>
        <translation>MediaPlayer</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Geral</translation>
    </message>
    <message>
        <source>MPRIS Player</source>
        <translation>MPRIS Player</translation>
    </message>
</context>
<context>
    <name>MPRISPlayerConfigurationUiHandler</name>
    <message>
        <source>Select Player:</source>
        <translation>Selecione o player:</translation>
    </message>
    <message>
        <source>Add Player</source>
        <translation>Adicionar player</translation>
    </message>
    <message>
        <source>Edit Player</source>
        <translation>Editar player</translation>
    </message>
    <message>
        <source>Delete Player</source>
        <translation>Apagar player</translation>
    </message>
</context>
<context>
    <name>MPRISPlayerDialog</name>
    <message>
        <source>Add Player</source>
        <translation>Adicionar player</translation>
    </message>
    <message>
        <source>Edit Player</source>
        <translation>Editar player</translation>
    </message>
    <message>
        <source>Player:</source>
        <translation>Player: </translation>
    </message>
    <message>
        <source>Service:</source>
        <translation>Serviço:</translation>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/mprisplayer_mediaplayer/translations/mprisplayer_mediaplayer_pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>MediaPlayer</source>
        <translation>MediaPlayer</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Geral</translation>
    </message>
    <message>
        <source>MPRIS Player</source>
        <translation>MPRIS Player</translation>
    </message>
</context>
<context>
    <name>MPRISPlayerConfigurationUiHandler</name>
    <message>
        <source>Select Player:</source>
        <translation>Selecione o player:</translation>
    </message>
    <message>
        <source>Add Player</source>
        <translation>Adicionar player</translation>
    </message>
    <message>
        <source>Edit Player</source>
        <translation>Editar player</translation>
    </message>
    <message>
        <source>Delete Player</source>
        <translation>Apagar player</translation>
    </message>
</context>
<context>
    <name>MPRISPlayerDialog</name>
    <message>
        <source>Add Player</source>
        <translation>Adicionar player</translation>
    </message>
    <message>
        <source>Edit Player</source>
        <translation>Editar player</translation>
    </message>
    <message>
        <source>Player:</source>
        <translation>Player: </translation>
    </message>
    <message>
        <source>Service:</source>
        <translation>Serviço:</translation>
    </message>
</context>
</TS>
